# DS_EMER

ds_emer es una libreria de prueba.

## Instalación

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install ds_emer.

```bash
pip install de_emer

## Usage

```python
from ds_emer import *

# Funcion Euge
a = euge()

# Funcion Agus
a = agus()
```

## Contribuciones

No son necesarias.